@@ -52,7 +52,7 @@ class DefaultTaskTrainerBuildContext(TaskTrainerBuildContext):
         if self._task_model: return self._task_model
         self._task_model = TaskModelFactory(self._task_context.task_name,
                                             self.config.model_config,
-                                            self._task_context.model_class()).get_task_model(model_path, for_train)
+                                            self._task_context.model_class).get_task_model(model_path, for_train)
         return self._task_model
 
 
