@@ -1,9 +1,9 @@
 from typing import Dict, NamedTuple, Optional, List, Union
 import numpy as np
 import torch
-from dataclasses import dataclass
-from transformers import DataCollator
+
 from transformers.data.data_collator import InputDataClass
+from transformers.data.metrics import acc_and_f1
 
 
 class TaskEvalPrediction(NamedTuple):
@@ -24,9 +24,8 @@ class TaskTrainOutput(NamedTuple):
     training_loss: float
 
 
-@dataclass
-class TaskDefaultDataCollatorx(DataCollator):
-    def collate_batch(self, features: List[InputDataClass]) -> Dict[str, torch.Tensor]:
+class TaskDefaultDataCollatorx():
+    def __call__(self, features: List[InputDataClass]) -> Dict[str, torch.Tensor]:
         first = features[0]
 
         # Special handling for labels.
@@ -56,6 +55,3 @@ class TaskDefaultDataCollatorx(DataCollator):
             if k not in ("guid", "label", "label_ids") and v is not None and not isinstance(v, str):
                 batch[k] = torch.tensor([getattr(f, k) for f in features], dtype=torch.long)
         return batch
-
-
-PREFIX_CHECKPOINT_DIR = "checkpoint"
